@@ -2,22 +2,18 @@
 
 .. currentmodule:: nbproject
 
-Display metadata with default arguments and start tracking with class instance `header`::
-
-   from nbproject import header
-
-.. autosummary::
-   :toctree:
-
-   Header
-
-Publish your notebook before sharing it with someone to ensure they can reproduce it.
+Most users will only need these two functions:
 
 .. autosummary::
    :toctree:
 
+   header
    publish
 
+Use them with default arguments after importing them like this::
+
+   from nbproject import header, publish
+
 To access metadata use the class instance `meta`::
 
    from nbproject import meta
@@ -32,6 +28,7 @@ It offers access to `meta.store` and `meta.live`:
 .. autosummary::
    :toctree:
 
+   MetaContainer
    MetaStore
    MetaLive
 
@@ -43,11 +40,11 @@ For more fine-grained access, we offer a developer API:
    dev
 
 """
-__version__ = "0.1.5"
+__version__ = "0.2.1"
 
 from . import dev
-from ._header import Header  # noqa
-from ._meta import Meta, MetaLive, MetaStore
+from ._header import header  # noqa
+from ._meta import Meta, MetaContainer, MetaLive, MetaStore
 from ._publish import publish
 
 _meta = None
