@@ -1,17 +1,16 @@
 from datetime import datetime, timezone
 from pathlib import Path
 
-import orjson
-
-from ._header import nbproject_id
 from ._utils import public_fields
+from .dev._initialize import nbproject_id
+from .dev._notebook import Notebook, write_notebook
 
 
 class NBRecord:
-    def __init__(self, nb: dict):
+    def __init__(self, nb: Notebook):
         self._nb = nb
 
-        metadata = nb["metadata"]
+        metadata = nb.metadata
         if "nbproject" in metadata:
             self._filled = True
             for key, value in metadata["nbproject"].items():
@@ -51,6 +50,14 @@ class NBRecord:
             self._time_init = time_init
         return time_init
 
+    @property
+    def version(self):
+        version = self.check_attr("_version")
+        if version is None:
+            version = "draft"
+            self._version = "draft"
+        return version
+
     @property
     def dependency(self):
         if "dependency" in self.__dict__:
@@ -63,15 +70,14 @@ class NBRecord:
     def write(self, nb_path: Path, overwrite: bool):
         nbproj_data = public_fields(self)
         if overwrite or not self._filled:
-            self._nb["metadata"]["nbproject"] = nbproj_data
-            with open(nb_path, "wb") as f:
-                f.write(orjson.dumps(self._nb))
+            self._nb.metadata["nbproject"] = nbproj_data
+            write_notebook(self._nb, nb_path)
             self._filled = True
 
 
 class YAMLRecord:
-    # this is for ordering and also ignore this than reading yaml fields
-    _take_keys = ("time_init", "name", "location")
+    # this is for ordering and also ignore this when reading yaml fields
+    _take_keys = ("time_init", "name", "version", "location")
 
     def __init__(self, nb_path: Path, nb_record: NBRecord, yaml_proj: dict):
         self._yaml_proj = yaml_proj
