@@ -3,7 +3,8 @@
 Features
 --------
 
-.. autofunction:: infer_dependencies
+.. autofunction:: infer_dependencies_from_nb
+.. autofunction:: infer_dependencies_from_file
 .. autofunction:: check_integrity
 
 Backend
@@ -15,8 +16,9 @@ Backend
 .. autofunction:: read_notebook
 .. autofunction:: write_notebook
 """
-from . import _test as test
-from ._dependency import infer_dependencies
+import nbproject_test as test
+
+from ._dependency import infer_dependencies_from_file, infer_dependencies_from_nb
 from ._initialize import initialize_metadata
 from ._integrity import check_integrity
 from ._jupyter_communicate import notebook_path
