@@ -14,5 +14,12 @@ def pytest_collection_modifyitems(session, config, items):
 
 
 def pytest_sessionfinish(session, exitstatus):
-    nbproj_file = Path(__file__).parents[1] / "docs/tutorials/nbproject_metadata.yml"
+    test_cli_folder = Path(__file__).parents[1] / "docs/guides/"
+
+    nbproj_file = test_cli_folder / "nbproject_metadata.yml"
     nbproj_file.unlink(missing_ok=True)
+
+    reqs_subfolders = ["", "example-project/"]
+    for reqs_subfolder in reqs_subfolders:
+        reqs_file = test_cli_folder / (reqs_subfolder + "requirments.txt")
+        reqs_file.unlink(missing_ok=True)
